@@ -8,7 +8,7 @@
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the GNU
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
@@ -43,26 +43,28 @@ G_BEGIN_DECLS
 #define GTK_ADJUSTMENT_GET_CLASS(obj)        (G_TYPE_INSTANCE_GET_CLASS ((obj), GTK_TYPE_ADJUSTMENT, GtkAdjustmentClass))
 
 
-typedef struct _GtkAdjustment	    GtkAdjustment;
-typedef struct _GtkAdjustmentClass  GtkAdjustmentClass;
+typedef struct _GtkAdjustment         GtkAdjustment;
+typedef struct _GtkAdjustmentPrivate  GtkAdjustmentPrivate;
+typedef struct _GtkAdjustmentClass    GtkAdjustmentClass;
 
+/**
+ * GtkAdjustment:
+ *
+ * The #GtkAdjustment struct contains only private fields and
+ * should not be directly accessed.
+ */
 struct _GtkAdjustment
 {
   GInitiallyUnowned parent_instance;
 
-  gdouble GSEAL (lower);
-  gdouble GSEAL (upper);
-  gdouble GSEAL (value);
-  gdouble GSEAL (step_increment);
-  gdouble GSEAL (page_increment);
-  gdouble GSEAL (page_size);
+  GtkAdjustmentPrivate *priv;
 };
 
 struct _GtkAdjustmentClass
 {
   GInitiallyUnownedClass parent_class;
 
-  void (* changed)	 (GtkAdjustment *adjustment);
+  void (* changed)       (GtkAdjustment *adjustment);
   void (* value_changed) (GtkAdjustment *adjustment);
 
   /* Padding for future expansion */
@@ -73,23 +75,23 @@ struct _GtkAdjustmentClass
 };
 
 
-GType	   gtk_adjustment_get_type		(void) G_GNUC_CONST;
-GtkAdjustment*   gtk_adjustment_new		(gdouble	  value,
-						 gdouble	  lower,
-						 gdouble	  upper,
-						 gdouble	  step_increment,
-						 gdouble	  page_increment,
-						 gdouble	  page_size);
+GType      gtk_adjustment_get_type              (void) G_GNUC_CONST;
+GtkAdjustment*   gtk_adjustment_new             (gdouble          value,
+                                                 gdouble          lower,
+                                                 gdouble          upper,
+                                                 gdouble          step_increment,
+                                                 gdouble          page_increment,
+                                                 gdouble          page_size);
 
-void	   gtk_adjustment_changed		(GtkAdjustment	 *adjustment);
-void	   gtk_adjustment_value_changed		(GtkAdjustment	 *adjustment);
-void	   gtk_adjustment_clamp_page		(GtkAdjustment	 *adjustment,
-						 gdouble	  lower,
-						 gdouble	  upper);
+void       gtk_adjustment_changed               (GtkAdjustment   *adjustment);
+void       gtk_adjustment_value_changed         (GtkAdjustment   *adjustment);
+void       gtk_adjustment_clamp_page            (GtkAdjustment   *adjustment,
+                                                 gdouble          lower,
+                                                 gdouble          upper);
 
-gdouble	   gtk_adjustment_get_value		(GtkAdjustment   *adjustment);
-void	   gtk_adjustment_set_value		(GtkAdjustment	 *adjustment,
-						 gdouble	  value);
+gdouble    gtk_adjustment_get_value             (GtkAdjustment   *adjustment);
+void       gtk_adjustment_set_value             (GtkAdjustment   *adjustment,
+                                                 gdouble          value);
 gdouble    gtk_adjustment_get_lower             (GtkAdjustment   *adjustment);
 void       gtk_adjustment_set_lower             (GtkAdjustment   *adjustment,
                                                  gdouble          lower);
@@ -108,11 +110,13 @@ void       gtk_adjustment_set_page_size         (GtkAdjustment   *adjustment,
 
 void       gtk_adjustment_configure             (GtkAdjustment   *adjustment,
                                                  gdouble          value,
-						 gdouble          lower,
-						 gdouble          upper,
-						 gdouble          step_increment,
-						 gdouble          page_increment,
-						 gdouble          page_size);
+                                                 gdouble          lower,
+                                                 gdouble          upper,
+                                                 gdouble          step_increment,
+                                                 gdouble          page_increment,
+                                                 gdouble          page_size);
+
+gdouble    gtk_adjustment_get_minimum_increment (GtkAdjustment   *adjustment);
 
 G_END_DECLS
 
